Chapter 1: Galaxies
===================

In chapter 1, we introduce you to galaxy morphology, structure and the core **PyAutoGalaxy** API.

**Binder** links to every tutorial are included.

The chapter contains the following tutorials:

`Tutorial 0: Visualization <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_1_introduction/tutorial_0_visualization.ipynb>`_
- Setting up **PyAutoGalaxy**'s visualization library.

`Tutorial 1: Grids And Galaxies <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_1_introduction/tutorial_1_grids_and_galaxies.ipynb>`_
- Using grids of (y,x) coordinates with galaxies made up of light profiles.

`Tutorial 2: Data <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_1_introduction/tutorial_2_data.ipynb>`_
- Simulating and inspecting telescope imaging data of a galaxy.

`Tutorial 3: Fitting <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_1_introduction/tutorial_3_fitting.ipynb>`_
- Fitting data with a galaxy model.

`Tutorial 4: Methods <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_1_introduction/tutorial_4_methods.ipynb>`_
- An overview of the different methods used to fit galaxies with.

`Tutorial 5: Summary <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_1_introduction/tutorial_5_summary.ipynb>`_
- A summary of the chapter.